@@ -1,12 +1,12 @@
 import os
-import requests
 from typing import Union
 
+import requests
+
 from .exceptions import FastLabelException, FastLabelInvalidException
 
 
 class Api:
-
     base_url = "https://api.fastlabel.ai/v1/"
     access_token = None
 
@@ -55,15 +55,17 @@ class Api:
         }
         r = requests.delete(self.base_url + endpoint, headers=headers, params=params)
 
-        if r.status_code != 204:
-            try:
-                error = r.json()["message"]
-            except ValueError:
-                error = r.text
-            if str(r.status_code).startswith("4"):
-                raise FastLabelInvalidException(error, r.status_code)
-            else:
-                raise FastLabelException(error, r.status_code)
+        if r.status_code == 200 or r.status_code == 204:
+            return
+
+        try:
+            error = r.json()["message"]
+        except ValueError:
+            error = r.text
+        if str(r.status_code).startswith("4"):
+            raise FastLabelInvalidException(error, r.status_code)
+        else:
+            raise FastLabelException(error, r.status_code)
 
     def post_request(self, endpoint, payload=None):
         """Makes a post request to an endpoint.
@@ -116,3 +118,11 @@ class Api:
                 raise FastLabelInvalidException(error, r.status_code)
             else:
                 raise FastLabelException(error, r.status_code)
+
+    def upload_zipfile(
+        self,
+        url: str,
+        file_path: str,
+    ):
+        files = {"file": open(file_path, "rb")}
+        return requests.put(url, files=files)
