@@ -1,5 +1,6 @@
 import math
 from enum import Enum
+from typing import List, Union
 
 # only 57 types
 COLOR_PALETTE = [
@@ -212,12 +213,23 @@ SUPPORTED_TEXT_SIZE = 2 * math.pow(1024, 2)
 # API can accept under 120 MB
 SUPPORTED_AUDIO_SIZE = 120 * math.pow(1024, 2)
 
-# API can accept under 30 MB
-SUPPORTED_PCD_SIZE = 30 * math.pow(1024, 2)
+# API can accept under 2GB
+SUPPORTED_DICOM_SIZE = 2000 * math.pow(1024, 2)
+
+# API can accept under 100 MB
+SUPPORTED_PCD_SIZE = 100 * math.pow(1024, 2)
+
+# API can accept under 250 MB
+SUPPORTED_OBJECT_SIZE = 250 * math.pow(1024, 2)
+
+# Only 'avc1' and 'H264' are supported for video task creation.
+SUPPORTED_FOURCC = ["avc1", "h264"]
 
 
 SUPPORTED_INFERENCE_IMAGE_SIZE = 6 * math.pow(1024, 2)
 
+AttributeValue = Union[str, List[str], float, List[float]]
+
 
 class AnnotationType(Enum):
     bbox = "bbox"
@@ -228,3 +240,17 @@ class AnnotationType(Enum):
     segmentation = "segmentation"
     classification = "classification"
     pose_estimation = "pose_estimation"
+
+
+class Priority(Enum):
+    none = 0
+    low = 10
+    medium = 20
+    high = 30
+
+
+class DatasetObjectType(Enum):
+    none = "none"
+    train = "train"
+    valid = "valid"
+    test = "test"
