@@ -8,14 +8,14 @@ from decimal import Decimal
 from operator import itemgetter
 from pathlib import Path
 from tempfile import NamedTemporaryFile
-from typing import List, Optional
+from typing import List, Dict, Optional
 
 import cv2
 import geojson
 import numpy as np
 import requests
 
-from fastlabel.const import AnnotationType
+from fastlabel.const import AnnotationType, AttributeValue
 from fastlabel.exceptions import FastLabelInvalidException
 from fastlabel.utils import is_video_project_type
 
@@ -74,6 +74,9 @@ def to_coco(
                     "annotation_type": annotation["type"],
                     "annotation_points": get_annotation_points(annotation, index),
                     "annotation_keypoints": annotation.get("keypoints"),
+                    "annotation_attributes": _get_coco_annotation_attributes(
+                        annotation
+                    ),
                     "categories": categories,
                     "image_id": task_image["id"],
                 }
@@ -204,6 +207,7 @@ def __to_coco_annotation(data: dict) -> dict:
     annotation_type = data["annotation_type"]
     annotation_value = data["annotation_value"]
     annotation_id = 0
+    annotation_attributes = data["annotation_attributes"]
 
     if annotation_type not in [
         AnnotationType.bbox.value,
@@ -226,7 +230,13 @@ def __to_coco_annotation(data: dict) -> dict:
         return None
 
     return __get_coco_annotation(
-        annotation_id, points, keypoints, category["id"], image_id, annotation_type
+        annotation_id,
+        points,
+        keypoints,
+        category,
+        image_id,
+        annotation_type,
+        annotation_attributes,
     )
 
 
@@ -239,13 +249,11 @@ def __get_coco_category_by_name(categories: list, name: str) -> Optional[dict]:
     return None
 
 
-def __get_coco_annotation_keypoints(keypoints: list) -> list:
+def __get_coco_annotation_keypoints(keypoints: list, category_keypoints: list) -> list:
     coco_annotation_keypoints = []
-    for keypoint in keypoints:
-        value = keypoint["value"]
-        if not value:
-            coco_annotation_keypoints.extend([0, 0, 0])
-            continue
+    keypoint_values = {keypoint["key"]: keypoint["value"] for keypoint in keypoints if keypoint["value"]}
+    for category_key in category_keypoints:
+        value = keypoint_values.get(category_key, [0, 0, 0])
         # Adjust fastlabel data definition to coco format
         visibility = 2 if value[2] == 1 else 1
         coco_annotation_keypoints.extend([value[0], value[1], visibility])
@@ -256,22 +264,24 @@ def __get_coco_annotation(
     id_: int,
     points: list,
     keypoints: list,
-    category_id: int,
+    category: dict,
     image_id: str,
     annotation_type: str,
+    annotation_attributes: Dict[str, AttributeValue],
 ) -> dict:
     annotation = {}
     annotation["num_keypoints"] = len(keypoints) if keypoints else 0
     annotation["keypoints"] = (
-        __get_coco_annotation_keypoints(keypoints) if keypoints else []
+        __get_coco_annotation_keypoints(keypoints, category["keypoints"]) if keypoints else []
     )
     annotation["segmentation"] = __to_coco_segmentation(annotation_type, points)
     annotation["iscrowd"] = 0
     annotation["area"] = __to_area(annotation_type, points)
     annotation["image_id"] = image_id
     annotation["bbox"] = __to_bbox(annotation_type, points)
-    annotation["category_id"] = category_id
+    annotation["category_id"] = category["id"]
     annotation["id"] = id_
+    annotation["attributes"] = annotation_attributes
     return annotation
 
 
@@ -832,8 +842,10 @@ def execute_coco_to_fastlabel(coco: dict, annotation_type: str) -> dict:
     coco_categories = {}
     coco_categories_keypoints = {}
     for c in coco["categories"]:
-        coco_categories[c["id"]] = c["supercategory"]
-        coco_categories_keypoints[c["id"]] = c["keypoints"]
+        coco_categories[c["id"]] = c["name"] if c.get("name") else c["supercategory"]
+        coco_categories_keypoints[c["id"]] = (
+            c["keypoints"] if c.get("keypoints") else []
+        )
 
     coco_annotations = coco["annotations"]
 
@@ -848,6 +860,11 @@ def execute_coco_to_fastlabel(coco: dict, annotation_type: str) -> dict:
 
         annotations = []
         for target_coco_annotation in target_coco_annotations:
+            attributes_items = target_coco_annotation.get("attributes", {})
+            attributes = [
+                {"key": attribute_key, "value": attribute_value}
+                for attribute_key, attribute_value in attributes_items.items()
+            ]
             category_name = coco_categories[target_coco_annotation["category_id"]]
             if not category_name:
                 return
@@ -867,6 +884,7 @@ def execute_coco_to_fastlabel(coco: dict, annotation_type: str) -> dict:
                         "value": category_name,
                         "points": segmentation,
                         "type": annotation_type,
+                        "attributes": attributes,
                     }
                 )
             elif annotation_type == AnnotationType.pose_estimation.value:
@@ -898,6 +916,7 @@ def execute_coco_to_fastlabel(coco: dict, annotation_type: str) -> dict:
                         "value": category_name,
                         "type": annotation_type,
                         "keypoints": keypoints,
+                        "attributes": attributes,
                     }
                 )
             else:
@@ -1107,3 +1126,14 @@ def _get_annotation_points_for_video_annotation(annotation: dict, index: int):
 
 def _get_annotation_points_for_image_annotation(annotation: dict):
     return annotation.get("points")
+
+
+def _get_coco_annotation_attributes(annotation: dict) -> Dict[str, AttributeValue]:
+    coco_attributes = {}
+    attributes = annotation.get("attributes")
+    if not attributes:
+        return coco_attributes
+    for attribute in attributes:
+        coco_attributes[attribute["key"]] = attribute["value"]
+    return coco_attributes
+
